Package: matrixcalc
Version: 1.0-6
Date: 2022-09-10
Title: Collection of Functions for Matrix Calculations
Author: Frederick Novomestky <fnovomes@poly.edu>
Maintainer: S. Thomas Kelly <tomkellygenetics@gmail.com>
Depends: R (>= 2.0.1)
Description: A collection of functions to support matrix calculations
        for probability, econometric and numerical analysis. There are
        additional functions that are comparable to APL functions which
        are useful for actuarial models such as pension mathematics.
        This package is used for teaching and research purposes at the
        Department of Finance and Risk Engineering, New York
        University, Polytechnic Institute, Brooklyn, NY 11201.
        Horn, R.A. (1990) Matrix Analysis. ISBN 978-0521386326.
        Lancaster, P. (1969) Theory of Matrices. ISBN 978-0124355507.
        Lay, D.C. (1995) Linear Algebra: And Its Applications. ISBN 978-0201845563.
License: GPL (>= 2)
BugReports: https://github.com/TomKellyGenetics/matrixcalc/issues
Packaged: 2022-09-14 20:41:38 UTC; tom
Repository: CRAN
Date/Publication: 2022-09-14 21:20:02 UTC
RoxygenNote: 7.1.2
NeedsCompilation: no
Built: R 4.6.0; ; 2026-04-26 09:44:46 UTC; unix
