exportPattern( "^[[:alpha:]]+" )
export( "commutation.matrix",
        "creation.matrix",
        "D.matrix",
        "direct.prod",
        "direct.sum",
        "duplication.matrix",
        "E.matrices",
        "elimination.matrix",
        "entrywise.norm",
        "fibonacci.matrix",
        "frobenius.matrix",
        "frobenius.norm",
        "frobenius.prod",
        "H.matrices",
        "hadamard.prod",
        "hankel.matrix",
        "hilbert.matrix",
        "hilbert.schmidt.norm",
        "inf.norm",
        "is.diagonal.matrix",
        "is.idempotent.matrix",
        "is.indefinite",
        "is.negative.definite",
        "is.negative.semi.definite",
        "is.non.singular.matrix",
        "is.positive.definite",
        "is.positive.semi.definite",
        "is.singular.matrix",
        "is.skew.symmetric.matrix",
        "is.square.matrix",
        "is.symmetric.matrix",
        "K.matrix",
        "L.matrix",
        "lower.triangle",
        "lu.decomposition",
        "matrix.inverse",
        "matrix.power",
        "matrix.rank",
        "matrix.trace",
        "maximum.norm",
        "N.matrix",
        "one.norm",
        "pascal.matrix",
        "%s%",
        "set.submatrix",
        "shift.down",
        "shift.left",
        "shift.right",
        "shift.up",
        "spectral.norm",
        "stirling.matrix",
        "svd.inverse",
        "symmetric.pascal.matrix",
        "T.matrices",
        "toeplitz.matrix",
        "u.vectors",
        "upper.triangle",
        "vandermonde.matrix",
        "vec",
        "vech" )
        